@@ -1,6 +1,6 @@
-#!/bin/sh
+#!/bin/bash
 
-#Copyright (C) since 2006 NTT DATA Corporation
+#Copyright (C) 2006 - 2008 NTT DATA Corporation
 #
 #This program is free software; you can redistribute it and/or
 #Modify it under the terms of the GNU General Public License
@@ -16,18 +16,41 @@ export EXEC_PATH=${0%/*}
 
 . ${EXEC_PATH}/install.cfg
 
+VERSION=`cat ${EXEC_PATH}/hinemos_agent/_version`
+
+echo ""
+echo "##################################################################"
+echo ""
+echo "      Operation Management Software Hinemos Agent"
+echo "                                     Installer Ver. ${VERSION}"
+echo ""
+echo "                  Copyright (C) 2006-2008 NTT DATA Corporation."
+echo ""
+echo "##################################################################"
 echo ""
-																				
-echo "###################################################################"
-echo "###                                                             ###"
-echo "### Operation Management Software Hinemos Agent                 ###"
-echo "###                                        Installer Ver 2.4.3  ###"
-echo "###                                                             ###"
-echo "###  Copyright (C) since 2006 NTT DATA Corporation.             ###"
-echo "###################################################################"
 
 
-EXEC_USER=`/usr/bin/whoami`
+#プラットフォームをチェック
+if [ ${PLATFORM} = "linux" ]; then
+	EXEC_USER=`/usr/bin/whoami`
+	
+elif [ ${PLATFORM} = "solaris" ]; then
+	EXEC_USER=`/usr/ucb/whoami`
+		
+else
+	echo ""
+	echo "ERROR Environment variavble [PLATFORM] is not correct."
+	echo "Please check the install.cfg."
+	echo ""
+	echo "----------------------------------------"
+	echo "Setting example of install.cfg"
+	echo "Linux	： PLATFORM=linux"
+	echo "Solaris	： PLATFORM=solaris"
+	echo "----------------------------------------"
+	exit 1
+fi
+
+
 HOSTS_FILE=/etc/hosts
 HOST=`hostname`
 
@@ -81,6 +104,7 @@ hosts_check() {
 		done
 	else
 		echo "OK"
+		echo ""
 	fi
 }
 
@@ -293,6 +317,63 @@ snmp_setting() {
 	fi
 }
 
+### syslog-ngのインストール(Linux)
+syslogng_install_linux() {
+			
+		#インストールチェック
+		rpm -q syslog-ng > /dev/null
+		
+		if [ "${?}" -eq "1" ] ; then		
+			# rpmインストール
+			rpm -ivh --force ${SYSLOG_NG_RPM}
+			
+			# syslog-ng.conf の編集
+			LOCAL_ADDR=`grep ${HOST} ${HOSTS_FILE} | grep -v "^\s*\#" | gawk '{print $1}'`
+			echo "#add for Hinemos Agent ${HINEMOS_VERSION}" >> /etc/syslog-ng/syslog-ng.conf
+			echo "filter f_hinemos_log { facility(user);  };" >> /etc/syslog-ng/syslog-ng.conf
+			echo "source s_netudp { udp(ip(${LOCAL_ADDR}) port(514)); };" >>/etc/syslog-ng/syslog-ng.conf
+			echo "log { source(s_netudp); filter(f_hinemos_log); destination(d_hinemos);};" >>/etc/syslog-ng/syslog-ng.conf
+			echo "destination d_hinemos { tcp(\"${IPADDR}\" port(514));};" >> /etc/syslog-ng/syslog-ng.conf
+			echo "log { source(s_local);filter(f_mesg);destination(d_hinemos);};" >> /etc/syslog-ng/syslog-ng.conf
+			
+			# syslogの停止、syslog-ng の起動
+			/etc/init.d/syslog stop
+			/etc/init.d/syslog-ng start
+			/sbin/chkconfig --level 2345 syslog off
+			/sbin/chkconfig --level 2345 syslog-ng on
+		else
+			echo "Warning : Syslog-ng has already been installed."
+			echo "Please change the setting referring to the installation manual."
+			sleep 2
+		fi
+}
+
+### syslog-ngのインストール(Solaris)
+syslogng_install_solaris() {
+
+	TMP_M=0
+	TMP_A=0
+	grep "add for Hinemos Manager" ${HINEMOS_AGENT_HOME}/${SYSLOG_NG_VERSION}/etc/syslog-ng.conf > /dev/null 2>&1 && TMP_M=1
+	grep "add for Hinemos Agent" ${HINEMOS_AGENT_HOME}/${SYSLOG_NG_VERSION}/etc/syslog-ng.conf > /dev/null 2>&1 && TMP_A=1
+
+	if [ "${TMP_M}" -eq 0 ] ; then
+		if [ "${TMP_A}" -eq 0 ] ; then
+			LOCAL_ADDR=`cat /etc/hosts | grep $HOSTNAME | awk '{print $1;}'`
+			echo "#add for Hinemos Agent ${HINEMOS_VERSION}" >>${HINEMOS_AGENT_HOME}/${SYSLOG_NG_VERSION}/etc/syslog-ng.conf
+			echo "filter f_hinemos_log { facility(user) and program(\"hinemos_log_agent\"); };" >> ${HINEMOS_AGENT_HOME}/${SYSLOG_NG_VERSION}/etc/syslog-ng.conf
+			echo "destination d_hinemos { tcp(\"${IPADDR}\" port(514));};" >> ${HINEMOS_AGENT_HOME}/${SYSLOG_NG_VERSION}/etc/syslog-ng.conf
+			echo "log { source(s_sys);filter(f_no_hinemos);filter(f_mesg);destination(d_hinemos);};" >> ${HINEMOS_AGENT_HOME}/${SYSLOG_NG_VERSION}/etc/syslog-ng.conf
+			echo "log { source(s_sys);filter(f_hinemos_log);destination(d_hinemos);};" >> ${HINEMOS_AGENT_HOME}/${SYSLOG_NG_VERSION}/etc/syslog-ng.conf
+	
+			svcadm disable system/system-log && svccfg -v delete -f system/system-log && svccfg -v import ${EXEC_PATH}/service/syslog-ng.xml && svcadm enable system/syslog-ng
+	
+			#ログローテーションの設定
+			sed  s/syslog.pid/syslog-ng.pid/g /etc/logadm.conf > /tmp/logadm.conf
+			cp /tmp/logadm.conf /etc/logadm.conf
+		fi
+	fi
+}
+
 
 ##
 ## syslog-ngのインストール
@@ -302,39 +383,56 @@ syslogng_install() {
 	#syslog-ngインストール
 	echo "Syslog-ng is installed."
 	
-	#インストールチェック
-	rpm -q syslog-ng > /dev/null
-	
-	if [ "${?}" -eq "1" ] ; then		
-		# rpmインストール
-		rpm -ivh --force ${SYSLOG_NG_RPM}
+	if [ ${PLATFORM} = "linux" ]; then
+		syslogng_install_linux
 		
-		# syslog-ng.conf の編集
-		LOCAL_ADDR=`grep ${HOST} ${HOSTS_FILE} | grep -v "^\s*\#" | gawk '{print $1}'`
-		echo "#add for Hinemos Agent ${HINEMOS_VERSION}" >> /etc/syslog-ng/syslog-ng.conf
-		echo "filter f_hinemos_log { facility(user);  };" >> /etc/syslog-ng/syslog-ng.conf
-		echo "source s_netudp { udp(ip(${LOCAL_ADDR}) port(514)); };" >>/etc/syslog-ng/syslog-ng.conf
-		echo "log { source(s_netudp); filter(f_hinemos_log); destination(d_hinemos);};" >>/etc/syslog-ng/syslog-ng.conf
-		echo "destination d_hinemos { tcp(\"${IPADDR}\" port(514));};" >> /etc/syslog-ng/syslog-ng.conf
-		echo "log { source(s_local);filter(f_mesg);destination(d_hinemos);};" >> /etc/syslog-ng/syslog-ng.conf
-		
-		# syslogの停止、syslog-ng の起動
-		/etc/init.d/syslog stop
-		/etc/init.d/syslog-ng start
-		/sbin/chkconfig --level 2345 syslog off
-		/sbin/chkconfig --level 2345 syslog-ng on
-	else
-		echo "Warning : Syslog-ng has already been installed."
-		echo "Please change the setting referring to the installation manual."
-		sleep 2
+	elif [ ${PLATFORM} = "solaris" ]; then
+		syslogng_install_solaris
+
 	fi
+
 }
 
 
+### syslog-ngのアンインストール(Linux)
+syslogng_uninstall_linux() {
+
+	rpm -q syslog-ng > /dev/null
+	if [ "${?}" = "0" ] ; then
+
+		#syslog-ngアンインストール
+		/etc/init.d/syslog-ng stop
+		/etc/init.d/syslog start
+		/sbin/chkconfig --level 2345 syslog-ng off
+		/sbin/chkconfig --level 2345 syslog on
+		rpm -e syslog-ng libevtlog0
+		echo "Syslog-ng was uninstalled."
+		echo ""
+		echo "The backup file of syslog-ng.conf was created."
+		echo "	/etc/syslog-ng/syslog-ng.conf.rpmsave"	
+		echo "Please confirm it after completing uninstallation."
+		
+	fi
+
+}
+
+### syslog-ngのアンインストール(Solaris)
+syslogng_uninstall_solaris() {
+
+	echo ""
+	svcadm disable system/syslog-ng	&& svccfg -v delete -f system/syslog-ng && svccfg -v import  /var/svc/manifest/system/system-log.xml && svcadm enable system/system-log
+	
+	#ログローテーションの設定
+	sed  s/syslog-ng.pid/syslog.pid/g /etc/logadm.conf > /tmp/logadm.conf
+	cp /tmp/logadm.conf /etc/logadm.conf
+
+}
+
 ##
 ## syslog-ngのアンインストール
 ##
 syslogng_uninstall() {
+
 	while [ 1 ] ;
 	do
 		echo ""
@@ -342,17 +440,11 @@ syslogng_uninstall() {
 		read ANS_SYS
 		case ${ANS_SYS} in
 			y|Y)
-  				#syslog-ngアンインストール
-				/etc/init.d/syslog-ng stop
-				/etc/init.d/syslog start
-    			/sbin/chkconfig --level 2345 syslog-ng off
-				/sbin/chkconfig --level 2345 syslog on
-				rpm -e syslog-ng libol
-				echo "Syslog-ng was uninstalled."
-				echo ""
-				echo "The backup file of syslog-ng.conf was created."
-				echo "	/etc/syslog-ng/syslog-ng.conf.rpmsave"	
-				echo "Please confirm it after completing uninstallation."
+				if [ ${PLATFORM} = "linux" ]; then
+					syslogng_uninstall_linux
+				elif [ ${PLATFORM} = "solaris" ]; then
+					syslogng_uninstall_solaris
+				fi
 				break
 				;;
 			n|N)
@@ -363,6 +455,7 @@ syslogng_uninstall() {
 				;;
 		esac
 	done
+	
 }
 
 ##
@@ -372,7 +465,7 @@ snmp_setting_remove() {
 	# バックアップファイルが存在する場合のみ実行
 	if [ -f ${HINEMOS_AGENT_HOME}/var/backup/snmpd.conf_bk ] ; then
 		echo "The setting of net-snmp is changed."
-		echo "Do you want to return the net-snmp setting to the setting of Hinemos agent pre-installation.？(Y/N)"
+		echo "Do you want to return the net-snmp setting to the setting of Hinemos agent pre-installation?(Y/N)"
 		while [ 1 ];
 		do
 			read ANS
@@ -434,14 +527,16 @@ do
 						hosts_check
 
 						# パッケージのチェック
-						rpm_check
+						if [ ${PLATFORM} = "linux" ]; then
+							rpm_check
+						fi
 
 						# インストールディレクトリの確認
 						installdir_check
 
-						while [ ! "${IPADDR}" ] ;
+						while [ 1 ] ;
 						do
-							echo -n "Please input the manager's IP Address --:"
+							echo -n "Please input the manager's IP Address :"
 							read IPADDR
 							echo "Is it ${IPADDRESS}? (Y/N default:Y)"
 							read IP_ANS
@@ -474,11 +569,11 @@ do
 						echo "Installing  JRE"
 						sleep 2
 						echo ""
-						cp ${EXEC_PATH}/${JRE_VERSION}-linux-i586.bin ${HINEMOS_AGENT_HOME}
+						cp ${EXEC_PATH}/${JRE_FILE_NAME} ${HINEMOS_AGENT_HOME}
 						CURRENT_DIR=`pwd`
 						cd ${HINEMOS_AGENT_HOME}
-						${HINEMOS_AGENT_HOME}/${JRE_VERSION}-linux-i586.bin
-						rm ${HINEMOS_AGENT_HOME}/${JRE_VERSION}-linux-i586.bin
+						${HINEMOS_AGENT_HOME}/${JRE_FILE_NAME}
+						rm ${HINEMOS_AGENT_HOME}/${JRE_FILE_NAME}
 						cd ${CURRENT_DIR}
 						echo ""
 
@@ -506,14 +601,16 @@ do
 						echo log4j.appender.syslog.SyslogHost=$HOST >> ${HINEMOS_AGENT_HOME}/lib/log_agent/log4j.properties
 						echo "" >> ${HINEMOS_AGENT_HOME}/lib/log_agent/log4j.properties
 						
-						# ログ出力先設定
+						# ログ転送エージェントのログ出力先設定
 						echo "" >> ${HINEMOS_AGENT_HOME}/lib/log_agent/log4j.properties
 						echo "### log directory setting ###" >> ${HINEMOS_AGENT_HOME}/lib/log_agent/log4j.properties
 						echo log4j.appender.file.File=${HINEMOS_AGENT_HOME}/var/log/logagent.log >> ${HINEMOS_AGENT_HOME}/lib/log_agent/log4j.properties
 						echo "" >> ${HINEMOS_AGENT_HOME}/lib/log_agent/log4j.properties
 			  
 						#Net-SNMPのセットアップ
-						snmp_setting
+						if [ ${PLATFORM} = "linux" ]; then
+							snmp_setting
+						fi
 						echo ""
 
 						#syslog-ngのセットアップ
@@ -544,10 +641,12 @@ do
 			case ${ANS} in
 				y|Y)
 					#プロセス終了の確認
-					ps axu | grep /agent/ | grep -v grep | grep hinemos > /dev/null
+					#ps axu | grep /agent/ | grep -v grep | grep hinemos > /dev/null
+					ps -ef | grep /agent/ | grep -v grep | grep hinemos > /dev/null
 	  				RET1=$?  
 
-	  				ps axu | grep /log_agent/ | grep -v grep | grep hinemos > /dev/null 
+	  				#ps axu | grep /log_agent/ | grep -v grep | grep hinemos > /dev/null 
+	  				ps -ef | grep /log_agent/ | grep -v grep | grep hinemos > /dev/null 
 	  				RET2=$?  
 				
 					if [ ${RET1} -eq 0 -o ${RET2} -eq 0 ]; then
@@ -559,14 +658,13 @@ do
 				
 				
 					#syslog-ngのアンインストール
-					rpm -q syslog-ng > /dev/null
-					if [ "${?}" = "0" ] ; then
-						syslogng_uninstall
-					fi
+					syslogng_uninstall					
 					echo ""
 
 					#net-snmpの設定変更
-					snmp_setting_remove
+					if [ ${PLATFORM} = "linux" ]; then
+						snmp_setting_remove
+					fi
 					echo ""
 
 					#Hinemosエージェントファイルの削除
