@@ -1,6 +1,6 @@
 #!/bin/sh
 
-#Copyright (C) since 2006 NTT DATA Corporation
+#Copyright (C) 2006 - 2008 NTT DATA Corporation
 #
 #This program is free software; you can redistribute it and/or
 #Modify it under the terms of the GNU General Public License
@@ -22,6 +22,6 @@ if [ -f $HINEMOS_AGENT_PID ] ; then
 	fi
 fi
 
-nohup $JAVA_PROC -cp $HINEMOS_AGENT_HOME/lib/agent:$HINEMOS_AGENT_HOME/lib/agent/agent.jar:$HINEMOS_AGENT_HOME/lib/commons-logging.jar:$HINEMOS_AGENT_HOME/lib/jbossall-client.jar:$HINEMOS_AGENT_HOME/lib/log4j.jar:$HINEMOS_AGENT_HOME/lib/JobManagementEJB.jar:$HINEMOS_AGENT_HOME/lib/RepositoryEJB.jar:$HINEMOS_AGENT_HOME/lib/clustercontrol.jar:$HINEMOS_AGENT_HOME/lib/hinemos-commons.jar com.clustercontrol.agent.Agent $HINEMOS_AGENT_HOME/lib/agent/Agent.properties 2>> ${HINEMOS_AGENT_HOME}/bin/job_nohup.out &
+nohup $JAVA_PROC -cp $HINEMOS_AGENT_HOME/lib/agent:$HINEMOS_AGENT_HOME/lib/agent/agent.jar:$HINEMOS_AGENT_HOME/lib/commons-logging-1.1.jar:$HINEMOS_AGENT_HOME/lib/javassist.jar:$HINEMOS_AGENT_HOME/lib/jboss-aop-jdk50.jar:$HINEMOS_AGENT_HOME/lib/jboss-messaging-client.jar:$HINEMOS_AGENT_HOME/lib/jboss-remoting.jar:$HINEMOS_AGENT_HOME/lib/jbossall-client.jar:$HINEMOS_AGENT_HOME/lib/log4j-1.2.14.jar:$HINEMOS_AGENT_HOME/lib/trove.jar:$HINEMOS_AGENT_HOME/lib/JobManagementEJB.jar:$HINEMOS_AGENT_HOME/lib/RepositoryEJB.jar:$HINEMOS_AGENT_HOME/lib/clustercontrol.jar:$HINEMOS_AGENT_HOME/lib/hinemos-commons.jar com.clustercontrol.agent.Agent $HINEMOS_AGENT_HOME/lib/agent/Agent.properties 2>> $HINEMOS_AGENT_HOME/bin/job_nohup.out &
 echo $! > $HINEMOS_AGENT_PID  
 echo "Agent started"
